package jdk.javadoc.internal.doclets.formats.html.resources;

public final class standard_zh_CN extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "doclet.All_Modules", "\u5168\u90E8\u6A21\u5757" },
            { "doclet.All_Packages", "\u6240\u6709\u7A0B\u5E8F\u5305" },
            { "doclet.Annotation_Type_Hierarchy", "\u6CE8\u91CA\u7C7B\u578B\u5206\u5C42\u7ED3\u6784" },
            { "doclet.Annotation_Type_Members", "\u6CE8\u91CA\u7C7B\u578B\u5143\u7D20" },
            { "doclet.Annotation_Types", "\u6CE8\u91CA\u7C7B\u578B" },
            { "doclet.ClassUse_Annotation", "\u6CE8\u91CA\u7C7B\u578B\u4E3A{0}\u7684{1}\u4E2D\u7684\u7C7B" },
            { "doclet.ClassUse_Classes.in.0.used.by.1", "{1}\u4F7F\u7528\u7684{0}\u4E2D\u7684\u7C7B" },
            { "doclet.ClassUse_ConstructorAnnotations", "\u6CE8\u91CA\u7C7B\u578B\u4E3A{0}\u7684{1}\u4E2D\u7684\u6784\u9020\u5668" },
            { "doclet.ClassUse_ConstructorArgs", "\u53C2\u6570\u7C7B\u578B\u4E3A{0}\u7684{1}\u4E2D\u7684\u6784\u9020\u5668" },
            { "doclet.ClassUse_ConstructorArgsTypeParameters", "\u7C7B\u578B\u53D8\u91CF\u7C7B\u578B\u4E3A{0}\u7684{1}\u4E2D\u7684\u6784\u9020\u5668\u53C2\u6570" },
            { "doclet.ClassUse_ConstructorParameterAnnotations", "\u6CE8\u91CA\u7C7B\u578B\u4E3A{0}\u7684{1}\u4E2D\u7684\u6784\u9020\u5668\u53C2\u6570" },
            { "doclet.ClassUse_ConstructorThrows", "\u629B\u51FA{0}\u7684{1}\u4E2D\u7684\u6784\u9020\u5668" },
            { "doclet.ClassUse_Field", "\u58F0\u660E\u4E3A{0}\u7684{1}\u4E2D\u7684\u5B57\u6BB5" },
            { "doclet.ClassUse_FieldAnnotations", "\u6CE8\u91CA\u7C7B\u578B\u4E3A{0}\u7684{1}\u4E2D\u7684\u5B57\u6BB5" },
            { "doclet.ClassUse_FieldTypeParameter", "\u7C7B\u578B\u53C2\u6570\u7C7B\u578B\u4E3A{0}\u7684{1}\u4E2D\u7684\u5B57\u6BB5" },
            { "doclet.ClassUse_ImplementingClass", "\u5B9E\u73B0{0}\u7684{1}\u4E2D\u7684\u7C7B" },
            { "doclet.ClassUse_MethodAnnotations", "\u6CE8\u91CA\u7C7B\u578B\u4E3A{0}\u7684{1}\u4E2D\u7684\u65B9\u6CD5" },
            { "doclet.ClassUse_MethodArgs", "\u53C2\u6570\u7C7B\u578B\u4E3A{0}\u7684{1}\u4E2D\u7684\u65B9\u6CD5" },
            { "doclet.ClassUse_MethodArgsTypeParameters", "\u7C7B\u578B\u53D8\u91CF\u7C7B\u578B\u4E3A{0}\u7684{1}\u4E2D\u7684\u65B9\u6CD5\u53C2\u6570" },
            { "doclet.ClassUse_MethodParameterAnnotations", "\u6CE8\u91CA\u7C7B\u578B\u4E3A{0}\u7684{1}\u4E2D\u7684\u65B9\u6CD5\u53C2\u6570" },
            { "doclet.ClassUse_MethodReturn", "\u8FD4\u56DE{0}\u7684{1}\u4E2D\u7684\u65B9\u6CD5" },
            { "doclet.ClassUse_MethodReturnTypeParameter", "\u8FD4\u56DE\u53D8\u91CF\u7C7B\u578B\u4E3A{0}\u7684\u7C7B\u578B\u7684{1}\u4E2D\u7684\u65B9\u6CD5" },
            { "doclet.ClassUse_MethodThrows", "\u629B\u51FA{0}\u7684{1}\u4E2D\u7684\u65B9\u6CD5" },
            { "doclet.ClassUse_MethodTypeParameter", "\u7C7B\u578B\u53C2\u6570\u7C7B\u578B\u4E3A{0}\u7684{1}\u4E2D\u7684\u65B9\u6CD5" },
            { "doclet.ClassUse_No.usage.of.0", "\u6CA1\u6709{0}\u7684\u7528\u6CD5" },
            { "doclet.ClassUse_PackageAnnotation", "\u6CE8\u91CA\u7C7B\u578B\u4E3A{0}\u7684\u7A0B\u5E8F\u5305" },
            { "doclet.ClassUse_Packages.that.use.0", "\u4F7F\u7528{0}\u7684\u7A0B\u5E8F\u5305" },
            { "doclet.ClassUse_Subclass", "{1}\u4E2D{0}\u7684\u5B50\u7C7B" },
            { "doclet.ClassUse_Subinterface", "{1}\u4E2D{0}\u7684\u5B50\u63A5\u53E3" },
            { "doclet.ClassUse_Title", "{0}\u7684\u4F7F\u7528" },
            { "doclet.ClassUse_TypeParameter", "\u7C7B\u578B\u53C2\u6570\u7C7B\u578B\u4E3A{0}\u7684{1}\u4E2D\u7684\u7C7B" },
            { "doclet.ClassUse_Uses.of.0.in.1", "{1}\u4E2D{0}\u7684\u4F7F\u7528" },
            { "doclet.Class_Hierarchy", "\u7C7B\u5206\u5C42\u7ED3\u6784" },
            { "doclet.Constructor_for", "{0}\u7684\u6784\u9020\u5668" },
            { "doclet.Contents", "\u76EE\u5F55" },
            { "doclet.Deprecated_API", "\u5DF2\u8FC7\u65F6\u7684 API" },
            { "doclet.Description", "\u8BF4\u660E" },
            { "doclet.Description_From_Class", "\u4ECE\u7C7B\u590D\u5236\u7684\u8BF4\u660E:" },
            { "doclet.Description_From_Interface", "\u4ECE\u63A5\u53E3\u590D\u5236\u7684\u8BF4\u660E:" },
            { "doclet.Detail", "\u8BE6\u7EC6\u8D44\u6599:" },
            { "doclet.Element", "\u5143\u7D20" },
            { "doclet.Enclosing_Class", "\u5C01\u95ED\u7C7B:" },
            { "doclet.Enclosing_Interface", "\u5C01\u95ED\u63A5\u53E3:" },
            { "doclet.Enum_Hierarchy", "\u679A\u4E3E\u5206\u5C42\u7ED3\u6784" },
            { "doclet.Error_in_grouplist", "\u9519\u8BEF\u7684 -group \u9009\u9879: {0} {1}" },
            { "doclet.File_error", "\u8BFB\u53D6\u6587\u4EF6\u65F6\u51FA\u9519: {0}" },
            { "doclet.For_Removal", "\u5F85\u5220\u9664" },
            { "doclet.Frames", "\u6846\u67B6" },
            { "doclet.Functional_Interface", "\u51FD\u6570\u63A5\u53E3:" },
            { "doclet.Functional_Interface_Message", "\u8FD9\u662F\u4E00\u4E2A\u51FD\u6570\u63A5\u53E3, \u56E0\u6B64\u53EF\u7528\u4F5C lambda \u8868\u8FBE\u5F0F\u6216\u65B9\u6CD5\u5F15\u7528\u7684\u8D4B\u503C\u76EE\u6807\u3002" },
            { "doclet.Generated_Docs_Untitled", "\u751F\u6210\u7684\u6587\u6863 (\u65E0\u6807\u9898)" },
            { "doclet.Groupname_already_used", "\u5728 -group \u9009\u9879\u4E2D, \u7EC4\u540D\u5DF2\u4F7F\u7528: {0}" },
            { "doclet.Help", "\u5E2E\u52A9" },
            { "doclet.Hierarchy_For_All_Packages", "\u6240\u6709\u7A0B\u5E8F\u5305\u7684\u5206\u5C42\u7ED3\u6784" },
            { "doclet.Hierarchy_For_Package", "\u7A0B\u5E8F\u5305{0}\u7684\u5206\u5C42\u7ED3\u6784" },
            { "doclet.Href_Annotation_Title", "{0}\u4E2D\u7684\u6CE8\u91CA" },
            { "doclet.Href_Class_Or_Interface_Title", "{0}\u4E2D\u7684\u7C7B\u6216\u63A5\u53E3" },
            { "doclet.Href_Class_Title", "{0}\u4E2D\u7684\u7C7B" },
            { "doclet.Href_Enum_Title", "{0}\u4E2D\u7684\u679A\u4E3E" },
            { "doclet.Href_Interface_Title", "{0}\u4E2D\u7684\u63A5\u53E3" },
            { "doclet.Href_Type_Param_Title", "{0}\u4E2D\u7684\u7C7B\u578B\u53C2\u6570" },
            { "doclet.Implementing_Classes", "\u6240\u6709\u5DF2\u77E5\u5B9E\u73B0\u7C7B:" },
            { "doclet.Index", "\u7D22\u5F15" },
            { "doclet.Inheritance_Tree", "\u7EE7\u627F\u6811" },
            { "doclet.Interface_Hierarchy", "\u63A5\u53E3\u5206\u5C42\u7ED3\u6784" },
            { "doclet.Interfaces", "\u63A5\u53E3" },
            { "doclet.MalformedURL", "\u683C\u5F0F\u9519\u8BEF\u7684 URL: {0}" },
            { "doclet.Method_in", "{0}\u4E2D\u7684\u65B9\u6CD5" },
            { "doclet.Module", "\u6A21\u5757" },
            { "doclet.Module_Sub_Nav", "\u6A21\u5757:" },
            { "doclet.Navigation", "\u5BFC\u822A" },
            { "doclet.New_Page", "NewPage" },
            { "doclet.NoFrames_specified", "--no-frames \u9009\u9879\u4E0D\u518D\u662F\u5FC5\u9700\u7684\uFF0C\u53EF\u80FD\n\u4F1A\u5728\u672A\u6765\u53D1\u884C\u7248\u4E2D\u5220\u9664\u6B64\u9009\u9879\u3002" },
            { "doclet.No_Frames", "\u65E0\u6846\u67B6" },
            { "doclet.No_Non_Deprecated_Classes_To_Document", "\u627E\u4E0D\u5230\u53EF\u4EE5\u6587\u6863\u5316\u7684\u672A\u8FC7\u65F6\u7684\u7C7B\u3002" },
            { "doclet.No_Script_Message", "\u60A8\u7684\u6D4F\u89C8\u5668\u5DF2\u7981\u7528 JavaScript\u3002" },
            { "doclet.None", "\u65E0" },
            { "doclet.Open_Module", "\u6253\u5F00\u6A21\u5757" },
            { "doclet.Other_Packages", "\u5176\u4ED6\u7A0B\u5E8F\u5305" },
            { "doclet.Overrides", "\u8986\u76D6:" },
            { "doclet.Overview", "\u6982\u89C8" },
            { "doclet.Package", "\u7A0B\u5E8F\u5305" },
            { "doclet.Package_Hierarchies", "\u7A0B\u5E8F\u5305\u5206\u5C42\u7ED3\u6784:" },
            { "doclet.ReferencedIn", "\u53C2\u8003\u4F4D\u7F6E" },
            { "doclet.Same_element_name_used", "\u5143\u7D20\u540D\u79F0\u6216\u6A21\u5F0F\u4F7F\u7528\u4E86\u4E24\u6B21: {0}" },
            { "doclet.Search_tag_in", "{0}\u4E2D\u7684\u641C\u7D22\u6807\u8BB0" },
            { "doclet.Skip_navigation_links", "\u8DF3\u8FC7\u5BFC\u822A\u94FE\u63A5" },
            { "doclet.Specified_By", "\u6307\u5B9A\u8005:" },
            { "doclet.Static_method_in", "{0}\u4E2D\u7684\u9759\u6001\u65B9\u6CD5" },
            { "doclet.Static_variable_in", "{0}\u4E2D\u7684\u9759\u6001\u53D8\u91CF" },
            { "doclet.Subclasses", "\u76F4\u63A5\u5DF2\u77E5\u5B50\u7C7B:" },
            { "doclet.Subinterfaces", "\u6240\u6709\u5DF2\u77E5\u5B50\u63A5\u53E3:" },
            { "doclet.Summary", "\u6982\u8981:" },
            { "doclet.System_Property", "\u7CFB\u7EDF\u5C5E\u6027" },
            { "doclet.Tree", "\u6811" },
            { "doclet.URL_error", "\u83B7\u53D6 URL \u65F6\u51FA\u9519: {0}" },
            { "doclet.Variable_in", "{0}\u4E2D\u7684\u53D8\u91CF" },
            { "doclet.Window_ClassUse_Header", "{0} {1}\u7684\u4F7F\u7528" },
            { "doclet.Window_Class_Hierarchy", "\u7C7B\u5206\u5C42\u7ED3\u6784" },
            { "doclet.Window_Deprecated_List", "\u5DF2\u8FC7\u65F6\u7684\u5217\u8868" },
            { "doclet.Window_Help_title", "API \u5E2E\u52A9" },
            { "doclet.Window_Overview_Summary", "\u6982\u89C8" },
            { "doclet.Window_Single_Index", "\u7D22\u5F15" },
            { "doclet.Window_Source_title", "\u6E90\u4EE3\u7801" },
            { "doclet.Window_Split_Index", "{0} - \u7D22\u5F15" },
            { "doclet.also", "\u5E76" },
            { "doclet.annotation_type_members", "\u6CE8\u91CA\u7C7B\u578B\u5143\u7D20" },
            { "doclet.annotation_types", "\u6CE8\u91CA\u7C7B\u578B" },
            { "doclet.build_version", "\u6807\u51C6 Doclet \u7248\u672C {0}" },
            { "doclet.for_removal", "\u5F85\u5220\u9664" },
            { "doclet.help.annotation_type.declaration", "\u6CE8\u91CA\u7C7B\u578B\u58F0\u660E" },
            { "doclet.help.annotation_type.description", "\u6CE8\u91CA\u7C7B\u578B\u8BF4\u660E" },
            { "doclet.help.annotation_type.intro", "\u6BCF\u4E2A\u6CE8\u91CA\u7C7B\u578B\u90FD\u6709\u5404\u81EA\u7684\u9875\u9762, \u5176\u4E2D\u5305\u542B\u4EE5\u4E0B\u90E8\u5206:" },
            { "doclet.help.class_interface.declaration", "\u7C7B\u6216\u63A5\u53E3\u58F0\u660E" },
            { "doclet.help.class_interface.description", "\u7C7B\u6216\u63A5\u53E3\u8BF4\u660E" },
            { "doclet.help.class_interface.head", "\u7C7B\u6216\u63A5\u53E3" },
            { "doclet.help.class_interface.implementations", "\u6240\u6709\u5DF2\u77E5\u5B9E\u73B0\u7C7B" },
            { "doclet.help.class_interface.inheritance_diagram", "\u7C7B\u7EE7\u627F\u56FE" },
            { "doclet.help.class_interface.intro", "\u6BCF\u4E2A\u7C7B, \u63A5\u53E3, \u5D4C\u5957\u7C7B\u548C\u5D4C\u5957\u63A5\u53E3\u90FD\u6709\u5404\u81EA\u7684\u9875\u9762\u3002\u5176\u4E2D\u6BCF\u4E2A\u9875\u9762\u90FD\u7531\u4E09\u90E8\u5206 (\u7C7B/\u63A5\u53E3\u8BF4\u660E, \u6982\u8981\u8868, \u4EE5\u53CA\u8BE6\u7EC6\u7684\u6210\u5458\u8BF4\u660E) \u7EC4\u6210:" },
            { "doclet.help.class_interface.subclasses", "\u76F4\u63A5\u5B50\u7C7B" },
            { "doclet.help.class_interface.subinterfaces", "\u6240\u6709\u5DF2\u77E5\u5B50\u63A5\u53E3" },
            { "doclet.help.class_interface.summary", "\u6982\u8981\u6761\u76EE\u6309\u5B57\u6BCD\u987A\u5E8F\u6392\u5217\uFF0C\u800C\u8BE6\u7EC6\u8BF4\u660E\u5219\u6309\u5176\u5728\u6E90\u4EE3\u7801\u4E2D\u51FA\u73B0\u7684\u987A\u5E8F\u6392\u5217\u3002\u8FD9\u6709\u52A9\u4E8E\u4FDD\u6301\u7A0B\u5E8F\u5458\u6240\u5EFA\u7ACB\u7684\u903B\u8F91\u5206\u7EC4\u3002" },
            { "doclet.help.constants.body", "{0}\u9875\u9762\u5217\u51FA\u4E86\u9759\u6001\u6700\u7EC8\u5B57\u6BB5\u53CA\u5176\u503C\u3002" },
            { "doclet.help.deprecated.body", "{0} \u9875\u9762\u5217\u51FA\u4E86\u6240\u6709\u5DF2\u8FC7\u65F6\u7684 API\u3002\u901A\u5E38\uFF0C\u7531\u4E8E\u5DF2\u8FC7\u65F6\u7684 API \u5B58\u5728\u7F3A\u70B9\u5E76\u4E14\u5DF2\u63D0\u4F9B\u66FF\u4EE3 API\uFF0C\u4E0D\u5EFA\u8BAE\u4F7F\u7528\u5DF2\u8FC7\u65F6\u7684 API\u3002\u5728\u5C06\u6765\u7684\u5B9E\u65BD\u4E2D\uFF0C\u53EF\u80FD\u4F1A\u5220\u9664\u5DF2\u8FC7\u65F6\u7684 API\u3002" },
            { "doclet.help.enum.declaration", "\u679A\u4E3E\u58F0\u660E" },
            { "doclet.help.enum.definition", "\u679A\u4E3E\u8BF4\u660E" },
            { "doclet.help.enum.intro", "\u6BCF\u4E2A\u679A\u4E3E\u90FD\u6709\u5404\u81EA\u7684\u9875\u9762, \u5176\u4E2D\u5305\u542B\u4EE5\u4E0B\u90E8\u5206:" },
            { "doclet.help.footnote", "\u6B64\u5E2E\u52A9\u6587\u4EF6\u9002\u7528\u4E8E\u7531\u6807\u51C6 doclet \u751F\u6210\u7684 API \u6587\u6863\u3002" },
            { "doclet.help.index.body", "{0} \u5305\u542B\u6240\u6709\u7C7B\u3001\u63A5\u53E3\u3001\u6784\u9020\u5668\u3001\u65B9\u6CD5\u548C\u5B57\u6BB5\u7684\u6309\u5B57\u6BCD\u987A\u5E8F\u6392\u5217\u7684\u7D22\u5F15\uFF0C\u4EE5\u53CA\u6240\u6709\u7A0B\u5E8F\u5305\u548C\u6240\u6709\u7C7B\u7684\u5217\u8868\u3002" },
            { "doclet.help.index.head", "\u7D22\u5F15" },
            { "doclet.help.intro", "\u6B64 API (\u5E94\u7528\u7A0B\u5E8F\u7F16\u7A0B\u63A5\u53E3) \u6587\u6863\u5305\u542B\u5BF9\u5E94\u4E8E\u5BFC\u822A\u680F\u4E2D\u7684\u9879\u76EE\u7684\u9875\u9762, \u5982\u4E0B\u6240\u8FF0\u3002" },
            { "doclet.help.main_heading", "\u6B64 API \u6587\u6863\u7684\u7EC4\u7EC7\u65B9\u5F0F" },
            { "doclet.help.module.intro", "\u6BCF\u4E2A\u6A21\u5757\u90FD\u6709\u4E00\u9875\uFF0C\u5176\u4E2D\u5305\u542B\u5B83\u7684\u7A0B\u5E8F\u5305\u3001\u4E0E\u5176\u4ED6\u6A21\u5757\u7684\u4F9D\u8D56\u5173\u7CFB\u548C\u670D\u52A1\u7684\u5217\u8868\u4EE5\u53CA\u6A21\u5757\u6982\u8981\u3002\u8FD9\u4E9B\u9875\u53EF\u4EE5\u5305\u542B\u4E09\u4E2A\u7C7B\u522B\uFF1A" },
            { "doclet.help.overview.modules.body", "{0} \u9875\u662F\u6B64 API \u6587\u6863\u7684\u9996\u9875\uFF0C\u63D0\u4F9B\u4E86\u6240\u6709\u6A21\u5757\u7684\u5217\u8868\u53CA\u5176\u6982\u8981\u3002\u6B64\u9875\u4E5F\u53EF\u80FD\u5305\u542B\u8FD9\u4E9B\u6A21\u5757\u7684\u603B\u4F53\u8BF4\u660E\u3002" },
            { "doclet.help.overview.packages.body", "{0} \u9875\u9762\u662F\u6B64 API \u6587\u6863\u7684\u9996\u9875, \u63D0\u4F9B\u4E86\u6240\u6709\u7A0B\u5E8F\u5305\u7684\u5217\u8868\u53CA\u5176\u6982\u8981\u3002\u6B64\u9875\u9762\u4E5F\u53EF\u80FD\u5305\u542B\u8FD9\u4E9B\u7A0B\u5E8F\u5305\u7684\u603B\u4F53\u8BF4\u660E\u3002" },
            { "doclet.help.package.intro", "\u6BCF\u4E2A\u7A0B\u5E8F\u5305\u90FD\u6709\u4E00\u9875\uFF0C\u5176\u4E2D\u5305\u542B\u5B83\u7684\u7C7B\u548C\u63A5\u53E3\u7684\u5217\u8868\u53CA\u5176\u6982\u8981\u3002\u8FD9\u4E9B\u9875\u53EF\u4EE5\u5305\u542B\u516D\u4E2A\u7C7B\u522B\uFF1A" },
            { "doclet.help.search.example", "{0} \u5C06\u4E0E {1} \u76F8\u5339\u914D" },
            { "doclet.help.search.head", "\u641C\u7D22" },
            { "doclet.help.search.intro", "\u53EF\u4EE5\u4F7F\u7528\u90E8\u5206\u6216\u5B8C\u6574\u540D\u79F0\u641C\u7D22\u6A21\u5757\u3001\u7A0B\u5E8F\u5305\u3001\u7C7B\u578B\u3001\u5B57\u6BB5\u3001\u65B9\u6CD5\u3001\u7CFB\u7EDF\u5C5E\u6027\u4EE5\u53CA API \u4E2D\u5B9A\u4E49\u7684\u5176\u4ED6\u672F\u8BED\u7684\u5B9A\u4E49\uFF0C\uFF08\u53EF\u9009\uFF09\u4E5F\u53EF\u4EE5\u4F7F\u7528\u201C\u9A7C\u5CF0\u5927\u5C0F\u5199\u5F0F\u201D\u7F29\u5199\u8FDB\u884C\u641C\u7D22\u3002\u4F8B\u5982\uFF1A" },
            { "doclet.help.search.refer", "\u6709\u5173\u641C\u7D22\u529F\u80FD\u7684\u5B8C\u6574\u8BF4\u660E\uFF0C\u8BF7\u53C2\u9605 {0}\u3002" },
            { "doclet.help.search.spec.title", "Javadoc \u641C\u7D22\u89C4\u8303" },
            { "doclet.help.search.spec.url", "https://docs.oracle.com/en/java/javase/{0}/docs/specs/javadoc/javadoc-search-spec.html" },
            { "doclet.help.serial_form.body", "\u6BCF\u4E2A\u53EF\u5E8F\u5217\u5316\u6216\u53EF\u5916\u90E8\u5316\u7684\u7C7B\u90FD\u6709\u5176\u5E8F\u5217\u5316\u5B57\u6BB5\u548C\u65B9\u6CD5\u7684\u8BF4\u660E\u3002\u6B64\u4FE1\u606F\u5BF9\u5B9E\u65BD\uFF08\u800C\u975E\u4F7F\u7528\uFF09API \u7684\u4EBA\u5458\u6709\u7528\u3002\u5C3D\u7BA1\u5BFC\u822A\u680F\u4E2D\u6CA1\u6709\u94FE\u63A5\uFF0C\u4F46\u60A8\u53EF\u4EE5\u901A\u8FC7\u4E0B\u5217\u65B9\u5F0F\u83B7\u53D6\u6B64\u4FE1\u606F\uFF1A\u8F6C\u81F3\u4EFB\u4F55\u5E8F\u5217\u5316\u7C7B\uFF0C\u7136\u540E\u5355\u51FB\u7C7B\u8BF4\u660E\u7684\u201C\u53E6\u8BF7\u53C2\u9605\u201D\u90E8\u5206\u4E2D\u7684\u201C\u5E8F\u5217\u5316\u5F62\u5F0F\u201D\u3002" },
            { "doclet.help.tree.head", "\u6811 (\u7C7B\u5206\u5C42\u7ED3\u6784)" },
            { "doclet.help.tree.intro", "\u5BF9\u4E8E\u6240\u6709\u7A0B\u5E8F\u5305\uFF0C\u90FD\u6709\u4E00\u4E2A {0} \u9875\uFF0C\u4EE5\u53CA\u6BCF\u4E2A\u7A0B\u5E8F\u5305\u7684\u5206\u5C42\u7ED3\u6784\u3002\u6BCF\u4E2A\u5206\u5C42\u7ED3\u6784\u9875\u90FD\u5305\u542B\u7C7B\u7684\u5217\u8868\u548C\u63A5\u53E3\u7684\u5217\u8868\u3002\u4ECE {1} \u5F00\u59CB\uFF0C\u6309\u7EE7\u627F\u7ED3\u6784\u5BF9\u7C7B\u8FDB\u884C\u6392\u5217\u3002\u63A5\u53E3\u4E0D\u4ECE {1} \u7EE7\u627F\u3002" },
            { "doclet.help.tree.overview", "\u67E5\u770B\u201C\u6982\u89C8\u201D\u9875\u9762\u65F6, \u5355\u51FB \"\u6811\" \u5C06\u663E\u793A\u6240\u6709\u7A0B\u5E8F\u5305\u7684\u5206\u5C42\u7ED3\u6784\u3002" },
            { "doclet.help.tree.package", "\u67E5\u770B\u7279\u5B9A\u7A0B\u5E8F\u5305\u3001\u7C7B\u6216\u63A5\u53E3\u9875\u65F6\uFF0C\u5355\u51FB\u201C\u6811\u201D\u5C06\u4EC5\u663E\u793A\u8BE5\u7A0B\u5E8F\u5305\u7684\u5206\u5C42\u7ED3\u6784\u3002" },
            { "doclet.help.use.body", "\u6BCF\u4E2A\u5DF2\u6587\u6863\u5316\u7684\u7A0B\u5E8F\u5305\u3001\u7C7B\u548C\u63A5\u53E3\u90FD\u6709\u5404\u81EA\u7684\u201C\u4F7F\u7528\u201D\u9875\u3002\u6B64\u9875\u4ECB\u7ECD\u4E86\u4F7F\u7528\u7ED9\u5B9A\u7C7B\u6216\u7A0B\u5E8F\u5305\u7684\u4EFB\u4F55\u90E8\u5206\u7684\u7A0B\u5E8F\u5305\u3001\u7C7B\u3001\u65B9\u6CD5\u3001\u6784\u9020\u5668\u548C\u5B57\u6BB5\u3002\u5BF9\u4E8E\u7ED9\u5B9A\u7684\u7C7B\u6216\u63A5\u53E3 A\uFF0C\u5176\u201C\u4F7F\u7528\u201D\u9875\u5305\u542B A \u7684\u5B50\u7C7B\u3001\u58F0\u660E\u4E3A A \u7684\u5B57\u6BB5\u3001\u8FD4\u56DE A \u7684\u65B9\u6CD5\u4EE5\u53CA\u5E26\u6709\u7C7B\u578B\u4E3A A \u7684\u53C2\u6570\u7684\u65B9\u6CD5\u548C\u6784\u9020\u5668\u3002\u8BBF\u95EE\u6B64\u9875\u7684\u65B9\u6CD5\u662F\uFF1A\u9996\u5148\u8F6C\u81F3\u7A0B\u5E8F\u5305\u3001\u7C7B\u6216\u63A5\u53E3\uFF0C\u7136\u540E\u5355\u51FB\u5BFC\u822A\u680F\u4E2D\u7684\u201C\u4F7F\u7528\u201D\u94FE\u63A5\u3002" },
            { "doclet.help.use.head", "\u4F7F\u7528" },
            { "doclet.in_class", "\u5728\u7C7B\u4E2D" },
            { "doclet.in_interface", "\u5728\u63A5\u53E3\u4E2D" },
            { "doclet.module", "\u6A21\u5757" },
            { "doclet.navAnnotationTypeMember", "\u5143\u7D20" },
            { "doclet.navAnnotationTypeOptionalMember", "\u53EF\u9009" },
            { "doclet.navAnnotationTypeRequiredMember", "\u5FC5\u9700" },
            { "doclet.navClassUse", "\u4F7F\u7528" },
            { "doclet.navConstructor", "\u6784\u9020\u5668" },
            { "doclet.navDeprecated", "\u5DF2\u8FC7\u65F6" },
            { "doclet.navEnum", "\u679A\u4E3E\u5E38\u91CF" },
            { "doclet.navField", "\u5B57\u6BB5" },
            { "doclet.navMethod", "\u65B9\u6CD5" },
            { "doclet.navModuleDescription", "\u8BF4\u660E" },
            { "doclet.navModules", "\u6A21\u5757" },
            { "doclet.navNested", "\u5D4C\u5957" },
            { "doclet.navPackages", "\u7A0B\u5E8F\u5305" },
            { "doclet.navProperty", "\u5C5E\u6027" },
            { "doclet.navServices", "\u670D\u52A1" },
            { "doclet.not.exhaustive", "\uFF08\u975E\u8BE6\u5C3D\uFF09" },
            { "doclet.package", "\u7A0B\u5E8F\u5305" },
            { "doclet.see.class_or_package_not_accessible", "\u6807\u8BB0{0}: \u65E0\u6CD5\u8BBF\u95EE\u5F15\u7528: {1}" },
            { "doclet.see.class_or_package_not_found", "\u6807\u8BB0{0}: \u627E\u4E0D\u5230\u5F15\u7528: {1}" },
            { "doclet.systemProperties", "\u7CFB\u7EDF\u5C5E\u6027" },
            { "doclet.systemPropertiesSummary", "\u7CFB\u7EDF\u5C5E\u6027\u6982\u8981" },
            { "doclet.tag.invalid_usage", "\u6807\u8BB0 {0} \u7684\u7528\u6CD5\u65E0\u6548" },
            { "doclet.usage.add-stylesheet.description", "\u7528\u4E8E\u6240\u751F\u6210\u6587\u6863\u7684\u5176\u4ED6\u6837\u5F0F\u8868\u6587\u4EF6" },
            { "doclet.usage.add-stylesheet.parameters", "<file>" },
            { "doclet.usage.allow-script-in-comments.description", "\u5141\u8BB8\u5728\u9009\u9879\u548C\u6CE8\u91CA\u4E2D\u4F7F\u7528 JavaScript" },
            { "doclet.usage.author.description", "\u5305\u542B @author \u6BB5" },
            { "doclet.usage.bottom.description", "\u5305\u542B\u6BCF\u4E2A\u9875\u9762\u7684\u5E95\u90E8\u6587\u672C" },
            { "doclet.usage.bottom.parameters", "<html-code>" },
            { "doclet.usage.charset.description", "\u7528\u4E8E\u8DE8\u5E73\u53F0\u67E5\u770B\u751F\u6210\u7684\u6587\u6863\u7684\u5B57\u7B26\u96C6" },
            { "doclet.usage.charset.parameters", "<charset>" },
            { "doclet.usage.d.description", "\u8F93\u51FA\u6587\u4EF6\u7684\u76EE\u6807\u76EE\u5F55" },
            { "doclet.usage.d.parameters", "<directory>" },
            { "doclet.usage.docencoding.description", "\u6307\u5B9A\u8F93\u51FA\u7684\u5B57\u7B26\u7F16\u7801" },
            { "doclet.usage.docencoding.parameters", "<name>" },
            { "doclet.usage.docfilessubdirs.description", "\u9012\u5F52\u590D\u5236\u6587\u6863\u6587\u4EF6\u5B50\u76EE\u5F55" },
            { "doclet.usage.doctitle.description", "\u5305\u542B\u6982\u89C8\u9875\u9762\u7684\u6807\u9898" },
            { "doclet.usage.doctitle.parameters", "<html-code>" },
            { "doclet.usage.excludedocfilessubdir.description", "\u6392\u9664\u5177\u6709\u7ED9\u5B9A\u540D\u79F0\u7684\u6240\u6709\u6587\u6863\u6587\u4EF6\u5B50\u76EE\u5F55" },
            { "doclet.usage.excludedocfilessubdir.parameters", "<name>:.." },
            { "doclet.usage.footer.description", "\u5305\u542B\u6BCF\u4E2A\u9875\u9762\u7684\u9875\u811A\u6587\u672C" },
            { "doclet.usage.footer.parameters", "<html-code>" },
            { "doclet.usage.frames.description", "\u5141\u8BB8\u5728\u751F\u6210\u7684\u8F93\u51FA\u4E2D\u4F7F\u7528\u5E27" },
            { "doclet.usage.group.description", "\u5C06\u6307\u5B9A\u7684\u5143\u7D20\u5728\u6982\u89C8\u9875\u9762\u4E0A\u5206\u7EC4\u5728\u4E00\u8D77" },
            { "doclet.usage.group.parameters", "<name> <g1>:<g2>..." },
            { "doclet.usage.header.description", "\u5305\u542B\u6BCF\u4E2A\u9875\u9762\u7684\u9875\u7709\u6587\u672C" },
            { "doclet.usage.header.parameters", "<html-code>" },
            { "doclet.usage.helpfile.description", "\u5305\u542B\u5E2E\u52A9\u94FE\u63A5\u6240\u94FE\u63A5\u5230\u7684\u6587\u4EF6" },
            { "doclet.usage.helpfile.parameters", "<file>" },
            { "doclet.usage.html5.description", "\u751F\u6210 HTML 5 \u8F93\u51FA\u3002\u6B64\u9009\u9879\u4E0D\u518D\u662F\u5FC5\u9700\u7684\u3002" },
            { "doclet.usage.javafx.description", "\u542F\u7528 JavaFX \u529F\u80FD" },
            { "doclet.usage.keywords.description", "\u968F\u7A0B\u5E8F\u5305, \u7C7B\u548C\u6210\u5458\u4FE1\u606F\u4E00\u8D77\u9644\u5E26 HTML \u5143\u6807\u8BB0" },
            { "doclet.usage.link.description", "\u521B\u5EFA\u6307\u5411 <url> \u4E2D\u7684 javadoc \u8F93\u51FA\u7684\u94FE\u63A5" },
            { "doclet.usage.link.parameters", "<url>" },
            { "doclet.usage.linkoffline.description", "\u4F7F\u7528 <url2> \u4E2D\u7684\u7A0B\u5E8F\u5305\u5217\u8868\u94FE\u63A5\u5230 <url1> \u4E2D\u7684\u6587\u6863" },
            { "doclet.usage.linkoffline.parameters", "<url1> <url2>" },
            { "doclet.usage.linksource.description", "\u4EE5 HTML \u683C\u5F0F\u751F\u6210\u6E90\u6587\u4EF6" },
            { "doclet.usage.main-stylesheet.description", "\u7528\u4E8E\u66F4\u6539\u751F\u6210\u6587\u6863\u7684\u6837\u5F0F\u7684\u6587\u4EF6" },
            { "doclet.usage.main-stylesheet.parameters", "<file>" },
            { "doclet.usage.no-frames.description", "\u7981\u6B62\u5728\u751F\u6210\u7684\u8F93\u51FA\u4E2D\u4F7F\u7528\u5E27\uFF08\u9ED8\u8BA4\u503C\uFF09" },
            { "doclet.usage.no-module-directories.description", "\u4E0D\u5C06\u6A21\u5757\u6587\u6863\u7684\u6587\u4EF6\u5206\u7EC4\u5230\n\u6A21\u5757\u7279\u5B9A\u7684\u76EE\u5F55\u4E2D" },
            { "doclet.usage.nocomment.description", "\u4E0D\u751F\u6210\u8BF4\u660E\u548C\u6807\u8BB0, \u53EA\u751F\u6210\u58F0\u660E" },
            { "doclet.usage.nodeprecated.description", "\u4E0D\u5305\u542B @deprecated \u4FE1\u606F" },
            { "doclet.usage.nodeprecatedlist.description", "\u4E0D\u751F\u6210\u5DF2\u8FC7\u65F6\u7684\u5217\u8868" },
            { "doclet.usage.nohelp.description", "\u4E0D\u751F\u6210\u5E2E\u52A9\u94FE\u63A5" },
            { "doclet.usage.noindex.description", "\u4E0D\u751F\u6210\u7D22\u5F15" },
            { "doclet.usage.nonavbar.description", "\u4E0D\u751F\u6210\u5BFC\u822A\u680F" },
            { "doclet.usage.nooverview.description", "\u4E0D\u751F\u6210\u6982\u89C8\u9875\u9762" },
            { "doclet.usage.noqualifier.description", "\u8F93\u51FA\u4E2D\u4E0D\u5305\u62EC\u9650\u5B9A\u7B26\u7684\u5217\u8868" },
            { "doclet.usage.noqualifier.parameters", "<name1>:<name2>:.." },
            { "doclet.usage.nosince.description", "\u4E0D\u5305\u62EC @since \u4FE1\u606F" },
            { "doclet.usage.notimestamp.description", "\u4E0D\u5305\u62EC\u9690\u85CF\u7684\u65F6\u95F4\u6233" },
            { "doclet.usage.notree.description", "\u4E0D\u751F\u6210\u7C7B\u5206\u5C42\u7ED3\u6784" },
            { "doclet.usage.override-methods.description", "\u5728\u8BE6\u7EC6\u8D44\u6599\u90E8\u5206\u6216\u6982\u8981\u90E8\u5206\u4E2D\u7684\u6587\u6863\u8986\u76D6\u65B9\u6CD5" },
            { "doclet.usage.override-methods.parameters", "(detail|summary)" },
            { "doclet.usage.overview.description", "\u4ECE HTML \u6587\u4EF6\u8BFB\u53D6\u6982\u89C8\u6587\u6863" },
            { "doclet.usage.overview.parameters", "<file>" },
            { "doclet.usage.serialwarn.description", "\u751F\u6210\u6709\u5173 @serial \u6807\u8BB0\u7684\u8B66\u544A" },
            { "doclet.usage.sourcetab.description", "\u6307\u5B9A\u6E90\u4E2D\u6BCF\u4E2A\u5236\u8868\u7B26\u5360\u636E\u7684\u7A7A\u683C\u6570" },
            { "doclet.usage.sourcetab.parameters", "<tab length>" },
            { "doclet.usage.splitindex.description", "\u5C06\u7D22\u5F15\u5206\u4E3A\u6BCF\u4E2A\u5B57\u6BCD\u5BF9\u5E94\u4E00\u4E2A\u6587\u4EF6" },
            { "doclet.usage.tag.description", "\u6307\u5B9A\u5355\u4E2A\u53C2\u6570\u5B9A\u5236\u6807\u8BB0" },
            { "doclet.usage.tag.parameters", "<name>:<locations>:<header>" },
            { "doclet.usage.taglet.description", "\u8981\u6CE8\u518C\u7684 Taglet \u7684\u5168\u9650\u5B9A\u540D\u79F0" },
            { "doclet.usage.tagletpath.description", "Taglet \u7684\u8DEF\u5F84" },
            { "doclet.usage.top.description", "\u5305\u542B\u6BCF\u4E2A\u9875\u9762\u7684\u9876\u90E8\u6587\u672C" },
            { "doclet.usage.top.parameters", "<html-code>" },
            { "doclet.usage.use.description", "\u521B\u5EFA\u7C7B\u548C\u7A0B\u5E8F\u5305\u7528\u6CD5\u9875\u9762" },
            { "doclet.usage.version.description", "\u5305\u542B @version \u6BB5" },
            { "doclet.usage.windowtitle.description", "\u6587\u6863\u7684\u6D4F\u89C8\u5668\u7A97\u53E3\u6807\u9898" },
            { "doclet.usage.windowtitle.parameters", "<text>" },
            { "doclet.usage.xdoclint-extended.description", "\u9488\u5BF9 javadoc\n\u6CE8\u91CA\u4E2D\u7684\u95EE\u9898\n                                  \u542F\u7528\u6216\u7981\u7528\u7279\u5B9A\u68C0\u67E5,\n                                  \u5176\u4E2D <\u7EC4> \u4E3A accessibility, html,\nmissing, reference \u6216 syntax \u4E4B\u4E00\u3002" },
            { "doclet.usage.xdoclint-extended.parameters", "(all|none|[-]<group>)" },
            { "doclet.usage.xdoclint-package.description", "\u5728\u7279\u5B9A\u7684\u7A0B\u5E8F\u5305\u4E2D\u542F\u7528\u6216\u7981\u7528\u68C0\u67E5\u3002<\u7A0B\u5E8F\u5305>\n\u662F\u9017\u53F7\u5206\u9694\u7684\u7A0B\u5E8F\u5305\u8BF4\u660E\u7B26\u5217\u8868\u3002\u7A0B\u5E8F\u5305\n\u8BF4\u660E\u7B26\u662F\u7A0B\u5E8F\u5305\u7684\u9650\u5B9A\u540D\u79F0\u6216\u7A0B\u5E8F\u5305\u540D\u79F0\n\u524D\u7F00\u540E\u8DDF .*, \u5B83\u6269\u5C55\u5230\u7ED9\u5B9A\u7A0B\u5E8F\u5305\u7684\u6240\u6709\n\u5B50\u7A0B\u5E8F\u5305\u3002\u5728\u7A0B\u5E8F\u5305\u8BF4\u660E\u7B26\u524D\u9762\u52A0\u4E0A - \u53EF\u4EE5\n\u4E3A\u6307\u5B9A\u7A0B\u5E8F\u5305\u7981\u7528\u68C0\u67E5\u3002" },
            { "doclet.usage.xdoclint-package.parameters", "([-]<packages>)" },
            { "doclet.usage.xdoclint.description", "\u4E3A javadoc \u6CE8\u91CA\u4E2D\u7684\u95EE\u9898\u542F\u7528\u5EFA\u8BAE\u7684\u68C0\u67E5" },
            { "doclet.usage.xdocrootparent.description", "\u5C06\u6587\u6863\u6CE8\u91CA\u4E2D\u51FA\u73B0\u7684\u6240\u6709\u540E\u8DDF /.. \u7684 @docRoot \u66FF\u6362\u4E3A\n<url>" },
            { "doclet.usage.xdocrootparent.parameters", "<url>" },
        };
    }
}
